==> camunda-engine-7.2.0-sources.jar: org/camunda/bpm/engine/impl/jobexecutor/ThreadPoolJobExecutor.java <==
/* Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.camunda.bpm.engine.impl.jobexecutor;

import java.util.List;
import java.util.concurrent.RejectedExecutionException;
import java.util.concurrent.ThreadPoolExecutor;

import org.camunda.bpm.engine.impl.ProcessEngineImpl;

/**
 * @author Daniel Meyer
 *
 */
public class ThreadPoolJobExecutor extends JobExecutor {

  protected ThreadPoolExecutor threadPoolExecutor;

  protected void startExecutingJobs() {
    startJobAcquisitionThread();
  }

  protected void stopExecutingJobs() {
    stopJobAcquisitionThread();
  }

  public void executeJobs(List<String> jobIds, ProcessEngineImpl processEngine) {
    try {
      threadPoolExecutor.execute(new ExecuteJobsRunnable(jobIds, processEngine));
      
    } catch (RejectedExecutionException e) {
      rejectedJobsHandler.jobsRejected(jobIds, processEngine);
      
    }
  }
  
  // getters / setters

  public ThreadPoolExecutor getThreadPoolExecutor() {
    return threadPoolExecutor;
  }
  
  public void setThreadPoolExecutor(ThreadPoolExecutor threadPoolExecutor) {
    this.threadPoolExecutor = threadPoolExecutor;
  }

}

==> camunda-engine-7.4.0-sources.jar: org/camunda/bpm/engine/impl/jobexecutor/ThreadPoolJobExecutor.java <==
/* Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.camunda.bpm.engine.impl.jobexecutor;

import java.util.List;
import java.util.concurrent.RejectedExecutionException;
import java.util.concurrent.ThreadPoolExecutor;

import org.camunda.bpm.engine.impl.ProcessEngineImpl;

/**
 * @author Daniel Meyer
 *
 */
public class ThreadPoolJobExecutor extends JobExecutor {

  protected ThreadPoolExecutor threadPoolExecutor;

  protected void startExecutingJobs() {
    startJobAcquisitionThread();
  }

  protected void stopExecutingJobs() {
    stopJobAcquisitionThread();
  }

  public void executeJobs(List<String> jobIds, ProcessEngineImpl processEngine) {
    try {
      threadPoolExecutor.execute(getExecuteJobsRunnable(jobIds, processEngine));

    } catch (RejectedExecutionException e) {

      logRejectedExecution(processEngine, jobIds.size());
      rejectedJobsHandler.jobsRejected(jobIds, processEngine, this);

    }
  }

  // getters / setters

  public ThreadPoolExecutor getThreadPoolExecutor() {
    return threadPoolExecutor;
  }

  public void setThreadPoolExecutor(ThreadPoolExecutor threadPoolExecutor) {
    this.threadPoolExecutor = threadPoolExecutor;
  }

}
